'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _reactIntl = require('react-intl');

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _isEqual = require('lodash/isEqual');

var _isEqual2 = _interopRequireDefault(_isEqual);

var _recordDataHelpers = require('../../helpers/recordDataHelpers');

var _SearchPanelContainer = require('../../containers/search/SearchPanelContainer');

var _SearchPanelContainer2 = _interopRequireDefault(_SearchPanelContainer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var messages = (0, _reactIntl.defineMessages)({
  title: {
    'id': 'relatedRecordPanel.title',
    'defaultMessage': 'Related {collectionName}'
  }
});

var getSearchDescriptor = function getSearchDescriptor(props) {
  var csid = props.csid,
      recordRelationUpdatedTimestamp = props.recordRelationUpdatedTimestamp,
      relatedRecordType = props.relatedRecordType;


  return {
    recordType: relatedRecordType,
    searchQuery: {
      rel: csid,
      p: 0,
      size: 5
    },
    seqID: recordRelationUpdatedTimestamp
  };
};

var propTypes = {
  color: _react.PropTypes.string,
  columnSetName: _react.PropTypes.string,
  config: _react.PropTypes.object,
  csid: _react.PropTypes.string,
  name: _react.PropTypes.string,
  recordData: _react.PropTypes.instanceOf(_immutable2.default.Map),
  // This use isn't detected by eslint.
  /* eslint-disable react/no-unused-prop-types */
  recordRelationUpdatedTimestamp: _react.PropTypes.string,
  /* eslint-enable react/no-unused-prop-types */
  recordType: _react.PropTypes.string,
  relatedRecordType: _react.PropTypes.string,
  onItemClick: _react.PropTypes.func
};

var RelatedRecordPanel = function (_Component) {
  _inherits(RelatedRecordPanel, _Component);

  function RelatedRecordPanel(props) {
    _classCallCheck(this, RelatedRecordPanel);

    var _this = _possibleConstructorReturn(this, (RelatedRecordPanel.__proto__ || Object.getPrototypeOf(RelatedRecordPanel)).call(this, props));

    _this.handleSearchDescriptorChange = _this.handleSearchDescriptorChange.bind(_this);

    _this.state = {
      searchDescriptor: getSearchDescriptor(props)
    };
    return _this;
  }

  _createClass(RelatedRecordPanel, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      var searchDescriptor = getSearchDescriptor(this.props);
      var nextSearchDescriptor = getSearchDescriptor(nextProps);

      if (!(0, _isEqual2.default)(searchDescriptor, nextSearchDescriptor)) {
        if (searchDescriptor.recordType === nextSearchDescriptor.recordType && searchDescriptor.searchQuery.rel === nextSearchDescriptor.searchQuery.rel) {
          // The record type and related csid didn't change, so carry over the page number, size, and
          // sort from the current search descriptor.

          var _state$searchDescript = this.state.searchDescriptor.searchQuery,
              p = _state$searchDescript.p,
              size = _state$searchDescript.size,
              sort = _state$searchDescript.sort;


          nextSearchDescriptor.searchQuery.p = p;
          nextSearchDescriptor.searchQuery.size = size;
          nextSearchDescriptor.searchQuery.sort = sort;
        }

        this.setState({
          searchDescriptor: nextSearchDescriptor
        });
      }
    }
  }, {
    key: 'handleSearchDescriptorChange',
    value: function handleSearchDescriptorChange(searchDescriptor) {
      this.setState({
        searchDescriptor: searchDescriptor
      });
    }
  }, {
    key: 'renderTitle',
    value: function renderTitle() {
      var _props = this.props,
          config = _props.config,
          relatedRecordType = _props.relatedRecordType;


      var collectionNameMessage = (0, _get2.default)(config, ['recordTypes', relatedRecordType, 'messages', 'record', 'collectionName']);

      var collectionName = _react2.default.createElement(_reactIntl.FormattedMessage, collectionNameMessage);

      return _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.title, { values: { collectionName: collectionName } }));
    }
  }, {
    key: 'render',
    value: function render() {
      var _props2 = this.props,
          color = _props2.color,
          columnSetName = _props2.columnSetName,
          config = _props2.config,
          csid = _props2.csid,
          name = _props2.name,
          recordData = _props2.recordData,
          recordType = _props2.recordType,
          onItemClick = _props2.onItemClick;
      var searchDescriptor = this.state.searchDescriptor;


      if (!(0, _recordDataHelpers.getUpdatedTimestamp)(recordData)) {
        // Don't render until after the record has loaded.

        return null;
      }

      return _react2.default.createElement(_SearchPanelContainer2.default, {
        collapsed: true,
        color: color,
        columnSetName: columnSetName,
        config: config,
        csid: csid,
        name: name,
        searchDescriptor: searchDescriptor,
        recordType: recordType,
        title: this.renderTitle(),
        onItemClick: onItemClick,
        onSearchDescriptorChange: this.handleSearchDescriptorChange
      });
    }
  }]);

  return RelatedRecordPanel;
}(_react.Component);

exports.default = RelatedRecordPanel;


RelatedRecordPanel.propTypes = propTypes;