'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _immutable = require('immutable');

var _immutable2 = _interopRequireDefault(_immutable);

var _reactIntl = require('react-intl');

var _isEqual = require('lodash/isEqual');

var _isEqual2 = _interopRequireDefault(_isEqual);

var _RecordEditorContainer = require('../../containers/record/RecordEditorContainer');

var _RecordEditorContainer2 = _interopRequireDefault(_RecordEditorContainer);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var messages = (0, _reactIntl.defineMessages)({
  notFound: {
    'id': 'relationEditor.notFound',
    'defaultMessage': 'Not Found'
  },
  noRelation: {
    'id': 'relationEditor.noRelation',
    'defaultMessage': 'There is no related record with CSID "{csid}" and type "{recordType}".'
  }
});

var propTypes = {
  cloneCsid: _react.PropTypes.string,
  config: _react.PropTypes.object,
  // TODO: These uses aren't properly detected. Try updating eslint-plugin-react.
  /* eslint-disable react/no-unused-prop-types */
  subject: _react.PropTypes.shape({
    csid: _react.PropTypes.string
  }),
  object: _react.PropTypes.shape({
    csid: _react.PropTypes.string,
    recordType: _react.PropTypes.string
  }),
  /* eslint-enable react/no-unused-prop-types */
  predicate: _react.PropTypes.string,
  findResult: _react.PropTypes.instanceOf(_immutable2.default.Map),
  cloneRecord: _react.PropTypes.func,
  createRelation: _react.PropTypes.func,
  findRelation: _react.PropTypes.func,
  onRecordCreated: _react.PropTypes.func,
  onUnmount: _react.PropTypes.func
};

var RelationEditor = function (_Component) {
  _inherits(RelationEditor, _Component);

  function RelationEditor() {
    _classCallCheck(this, RelationEditor);

    var _this = _possibleConstructorReturn(this, (RelationEditor.__proto__ || Object.getPrototypeOf(RelationEditor)).call(this));

    _this.handleRecordCreated = _this.handleRecordCreated.bind(_this);
    return _this;
  }

  _createClass(RelationEditor, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      this.initRelation();
    }
  }, {
    key: 'componentDidUpdate',
    value: function componentDidUpdate(prevProps) {
      var _props = this.props,
          subject = _props.subject,
          object = _props.object,
          predicate = _props.predicate;
      var prevSubject = prevProps.subject,
          prevObject = prevProps.object,
          prevPredicate = prevProps.predicate;


      if (!(0, _isEqual2.default)(subject, prevSubject) || !(0, _isEqual2.default)(object, prevObject) || predicate !== prevPredicate) {
        this.initRelation();
      }
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      var onUnmount = this.props.onUnmount;


      if (onUnmount) {
        onUnmount();
      }
    }
  }, {
    key: 'initRelation',
    value: function initRelation() {
      var _props2 = this.props,
          config = _props2.config,
          subject = _props2.subject,
          object = _props2.object,
          predicate = _props2.predicate,
          findRelation = _props2.findRelation;


      if (findRelation && object.csid) {
        findRelation(config, {
          subject: subject,
          object: object,
          predicate: predicate
        });
      }
    }
  }, {
    key: 'handleRecordCreated',
    value: function handleRecordCreated(newRecordCsid) {
      var _props3 = this.props,
          subject = _props3.subject,
          predicate = _props3.predicate,
          createRelation = _props3.createRelation,
          onRecordCreated = _props3.onRecordCreated;


      if (createRelation) {
        var object = {
          csid: newRecordCsid
        };

        createRelation(subject, object, predicate).then(function () {
          if (onRecordCreated) {
            onRecordCreated(newRecordCsid);
          }
        });
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _props4 = this.props,
          cloneRecord = _props4.cloneRecord,
          cloneCsid = _props4.cloneCsid,
          config = _props4.config,
          subject = _props4.subject,
          object = _props4.object,
          findResult = _props4.findResult;


      if (object.csid) {
        if (!findResult) {
          return null;
        }

        // FIXME: Services should return a consistent (or no) namespace prefix.

        var list = findResult.get('ns2:relations-common-list') || findResult.get('ns3:relations-common-list');
        var count = parseInt(list.get('totalItems'), 10);

        if (isNaN(count) || count < 1) {
          // There is no relation.

          return _react2.default.createElement(
            'div',
            null,
            _react2.default.createElement(
              'h1',
              null,
              _react2.default.createElement(_reactIntl.FormattedMessage, messages.notFound)
            ),
            _react2.default.createElement(
              'p',
              null,
              _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.noRelation, {
                values: { csid: object.csid, recordType: object.recordType }
              }))
            )
          );
        }
      }

      return _react2.default.createElement(_RecordEditorContainer2.default, {
        cloneCsid: cloneCsid,
        config: config,
        csid: object.csid,
        recordType: object.recordType,
        relatedSubjectCsid: subject.csid,
        clone: cloneRecord,
        onRecordCreated: this.handleRecordCreated
      });
    }
  }]);

  return RelationEditor;
}(_react.Component);

exports.default = RelationEditor;


RelationEditor.propTypes = propTypes;