'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.default = SearchResultTitleBar;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactIntl = require('react-intl');

var _get = require('lodash/get');

var _get2 = _interopRequireDefault(_get);

var _CsidLink = require('../navigation/CsidLink');

var _CsidLink2 = _interopRequireDefault(_CsidLink);

var _TitleBar = require('../sections/TitleBar');

var _TitleBar2 = _interopRequireDefault(_TitleBar);

var _AdvancedSearchBuilder = require('./AdvancedSearchBuilder');

var _AdvancedSearchBuilder2 = _interopRequireDefault(_AdvancedSearchBuilder);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var messages = (0, _reactIntl.defineMessages)({
  title: {
    'id': 'searchResultTitleBar.title',
    'defaultMessage': 'Search Result'
  },
  keyword: {
    'id': 'searchResultTitleBar.keyword',
    'defaultMessage': 'containing {keyword}'
  },
  related: {
    'id': 'searchResultTitleBar.related',
    'defaultMessage': 'related to {record}'
  }
});

var propTypes = {
  config: _react.PropTypes.object,
  searchDescriptor: _react.PropTypes.object,
  searchName: _react.PropTypes.string
};

function SearchResultTitleBar(props) {
  var config = props.config,
      searchDescriptor = props.searchDescriptor,
      searchName = props.searchName;
  var recordType = searchDescriptor.recordType,
      vocabulary = searchDescriptor.vocabulary,
      csid = searchDescriptor.csid,
      subresource = searchDescriptor.subresource;


  var recordTypeConfig = (0, _get2.default)(config, ['recordTypes', recordType]);
  var vocabularyConfig = vocabulary ? (0, _get2.default)(recordTypeConfig, ['vocabularies', vocabulary]) : undefined;
  var subresourceConfig = subresource ? (0, _get2.default)(config, ['subresources', subresource]) : undefined;

  var _searchDescriptor$sea = searchDescriptor.searchQuery,
      advancedSearchCondition = _searchDescriptor$sea.as,
      kw = _searchDescriptor$sea.kw,
      rel = _searchDescriptor$sea.rel;


  var queryTitle = void 0;

  if (rel) {
    var recordLink = _react2.default.createElement(_CsidLink2.default, { config: config, searchName: searchName + '.rel', csid: rel });

    queryTitle = _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.related, {
      values: { record: recordLink }
    }));
  } else {
    queryTitle = kw ? _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.keyword, { values: { keyword: kw } })) : null;
  }

  var collectionName = void 0;

  if (subresourceConfig) {
    var _recordLink = _react2.default.createElement(_CsidLink2.default, { config: config, searchName: searchName + '.csid', csid: csid });

    collectionName = _react2.default.createElement(_reactIntl.FormattedMessage, _extends({}, subresourceConfig.messages.collectionName, {
      values: { record: _recordLink }
    }));
  } else if (vocabularyConfig) {
    collectionName = _react2.default.createElement(_reactIntl.FormattedMessage, vocabularyConfig.messages.collectionName);
  } else {
    collectionName = _react2.default.createElement(_reactIntl.FormattedMessage, recordTypeConfig.messages.record.collectionName);
  }

  var advancedTitle = void 0;

  if (advancedSearchCondition) {
    advancedTitle = _react2.default.createElement(_AdvancedSearchBuilder2.default, {
      condition: advancedSearchCondition,
      config: config,
      inline: true,
      readOnly: true,
      recordType: recordType
    });
  }

  var title = _react2.default.createElement(
    'div',
    null,
    collectionName,
    ' ',
    queryTitle
  );

  var aside = _react2.default.createElement(_reactIntl.FormattedMessage, messages.title);

  return _react2.default.createElement(_TitleBar2.default, { title: title, aside: aside, subtitle: advancedTitle });
}

SearchResultTitleBar.propTypes = propTypes;